@@ -73,6 +73,7 @@ lazy_static! {
                 ("BCH/USDT", 0.01_f64),
                 ("BCHA/USDT", 0.1_f64),
                 ("BEAM/USDT", 10_f64),
+                ("BICO/USDT", 0.1_f64),
                 ("BIT/USDT", 1_f64),
                 ("BNB/USDT", 0.001_f64),
                 ("BNT/USDT", 1_f64),
@@ -148,6 +149,7 @@ lazy_static! {
                 ("MASK/USDT", 0.1_f64),
                 ("MATIC/USDT", 10_f64),
                 ("MBABYDOGE/USDT", 100_f64),
+                ("MBOX/USDT", 0.1_f64),
                 ("MELON/USDT", 1_f64),
                 ("MINA/USDT", 0.1_f64),
                 ("MKISHU/USDT", 100_f64),
@@ -166,15 +168,18 @@ lazy_static! {
                 ("ONT/USDT", 1_f64),
                 ("OXY/USDT", 1_f64),
                 ("PEARL/USDT", 0.001_f64),
+                ("PEOPLE/USDT", 10_f64),
                 ("PERP/USDT", 0.1_f64),
                 ("POLS/USDT", 1_f64),
                 ("POLY/USDT", 1_f64),
                 ("POND/USDT", 10_f64),
                 ("PRIV/USDT", 0.001_f64),
                 ("QTUM/USDT", 1_f64),
+                ("RACA/USDT", 100_f64),
                 ("RAD/USDT", 0.1_f64),
                 ("RAY/USDT", 0.1_f64),
                 ("REEF/USDT", 100_f64),
+                ("REQ/USDT", 1_f64),
                 ("RNDR/USDT", 1_f64),
                 ("ROSE/USDT", 100_f64),
                 ("RUNE/USDT", 0.1_f64),
@@ -186,6 +191,7 @@ lazy_static! {
                 ("SLP/USDT", 1_f64),
                 ("SNX/USDT", 0.1_f64),
                 ("SOL/USDT", 1_f64),
+                ("SOS/USDT", 100000_f64),
                 ("SRM/USDT", 1_f64),
                 ("STORJ/USDT", 1_f64),
                 ("SUN/USDT", 0.1_f64),
