@@ -26,8 +26,10 @@ lazy_static! {
             ("BTC/USDT", 0.001_f64),
             ("BTT/USDT", 1000_f64),
             ("C98/USDT", 1_f64),
+            ("CHR/USDT", 1_f64),
             ("CHZ/USDT", 1_f64),
             ("COMP/USDT", 0.01_f64),
+            ("CRO/USDT", 1_f64),
             ("CRV/USDT", 1_f64),
             ("DASH/USDT", 0.01_f64),
             ("DENT/USDT", 100_f64),
@@ -41,13 +43,19 @@ lazy_static! {
             ("ETC/USDT", 0.1_f64),
             ("ETH/USDT", 0.01_f64),
             ("FIL/USDT", 0.1_f64),
+            ("FLOW/USDT", 0.1_f64),
             ("FTM/USDT", 1_f64),
+            ("GALA/USDT", 1_f64),
             ("GRT/USDT", 1_f64),
             ("HBAR/USDT", 10_f64),
             ("ICP/USDT", 0.01_f64),
             ("IOST/USDT", 100_f64),
+            ("IOTX/USDT", 10_f64),
+            ("KEEP/USDT", 1_f64),
             ("KSM/USDT", 0.01_f64),
+            ("LINA/USDT", 10_f64),
             ("LINK/USDT", 0.1_f64),
+            ("LRC/USDT", 1_f64),
             ("LTC/USDT", 0.1_f64),
             ("LUNA/USDT", 1_f64),
             ("MANA/USDT", 1_f64),
@@ -57,9 +65,12 @@ lazy_static! {
             ("NEAR/USDT", 0.1_f64),
             ("NEO/USDT", 0.1_f64),
             ("OCEAN/USDT", 1_f64),
+            ("OMG/USDT", 0.1_f64),
             ("ONE/USDT", 10_f64),
             ("ONT/USDT", 1_f64),
+            ("PEOPLE/USDT", 10_f64),
             ("QTUM/USDT", 0.1_f64),
+            ("RNDR/USDT", 1_f64),
             ("RVN/USDT", 10_f64),
             ("SAND/USDT", 1_f64),
             ("SHIB/USDT", 100000_f64),
@@ -68,11 +79,13 @@ lazy_static! {
             ("SUSHI/USDT", 1_f64),
             ("SXP/USDT", 1_f64),
             ("THETA/USDT", 0.1_f64),
+            ("TLM/USDT", 1_f64),
             ("TRX/USDT", 100_f64),
             ("UNI/USDT", 1_f64),
             ("VET/USDT", 100_f64),
             ("VRA/USDT", 10_f64),
             ("WAVES/USDT", 0.1_f64),
+            ("WAXP/USDT", 1_f64),
             ("XEM/USDT", 1_f64),
             ("XLM/USDT", 10_f64),
             ("XMR/USDT", 0.01_f64),
