@@ -21,6 +21,8 @@ lazy_static! {
             ("ALPHA/USDT", 1_f64),
             ("ANKR/USDT", 1_f64),
             ("ANT/USDT", 1_f64),
+            ("ANY/USDT", 0.1_f64),
+            ("APX/USDT", 10_f64),
             ("AR/USDT", 0.1_f64),
             ("ARPA/USDT", 1_f64),
             ("ATA/USDT", 1_f64),
@@ -35,7 +37,9 @@ lazy_static! {
             ("BAND/USDT", 0.1_f64),
             ("BAT/USDT", 1_f64),
             ("BCH/USDT", 0.01_f64),
+            ("BICO/USDT", 1_f64),
             ("BIT/USDT", 1_f64),
+            ("BLZ/USDT", 10_f64),
             ("BNB/USDT", 0.01_f64),
             ("BOBA/USDT", 1_f64),
             ("BP/USDT", 0.1_f64),
@@ -63,8 +67,10 @@ lazy_static! {
             ("CVC/USDT", 1_f64),
             ("DASH/USDT", 0.01_f64),
             ("DENT/USDT", 1_f64),
+            ("DERI/USDT", 10_f64),
             ("DGB/USDT", 1_f64),
             ("DOGE/USDT", 100_f64),
+            ("DORA/USDT", 0.1_f64),
             ("DOT/USDT", 0.1_f64),
             ("DYDX/USDT", 1_f64),
             ("EDEN/USDT", 1_f64),
@@ -78,7 +84,9 @@ lazy_static! {
             ("FILECOIN/USDT", 0.01_f64),
             ("FLM/USDT", 1_f64),
             ("FLOW/USDT", 0.1_f64),
+            ("FLUX/USDT", 1_f64),
             ("FODL/USDT", 1_f64),
+            ("FREE/USDT", 100_f64),
             ("FTM/USDT", 1_f64),
             ("FTT/USDT", 0.1_f64),
             ("GALA/USDT", 10_f64),
@@ -86,15 +94,20 @@ lazy_static! {
             ("GRT/USDT", 1_f64),
             ("GTC/USDT", 0.1_f64),
             ("HBAR/USDT", 1_f64),
+            ("HIVE/USDT", 1_f64),
             ("HNT/USDT", 0.1_f64),
             ("HOT/USDT", 1_f64),
             ("HT/USDT", 0.1_f64),
+            ("HTD/USDT", 1_f64),
             ("ICP/USDT", 0.01_f64),
             ("ICX/USDT", 1_f64),
+            ("ILV/USDT", 0.001_f64),
             ("IMX/USDT", 1_f64),
             ("IOST/USDT", 100_f64),
             ("IOTA/USDT", 1_f64),
             ("IOTX/USDT", 1_f64),
+            ("JASMY/USDT", 10_f64),
+            ("JOE/USDT", 1_f64),
             ("KAVA/USDT", 0.1_f64),
             ("KEEP/USDT", 1_f64),
             ("KISHU/USDT", 1000000000_f64),
@@ -118,6 +131,7 @@ lazy_static! {
             ("MTL/USDT", 1_f64),
             ("NEAR/USDT", 1_f64),
             ("NEO/USDT", 0.1_f64),
+            ("NFT/USDT", 1000000_f64),
             ("NKN/USDT", 1_f64),
             ("NU/USDT", 1_f64),
             ("O3/USDT", 1_f64),
@@ -127,22 +141,30 @@ lazy_static! {
             ("OMG/USDT", 0.1_f64),
             ("ONE/USDT", 1_f64),
             ("ONT/USDT", 1_f64),
+            ("PEOPLE/USDT", 10_f64),
             ("PIT/USDT", 1000000000_f64),
+            ("PLA/USDT", 1_f64),
             ("PSP/USDT", 1_f64),
             ("QTUM/USDT", 0.1_f64),
             ("RACA/USDT", 1000_f64),
             ("RAY/USDT", 0.1_f64),
             ("REEF/USDT", 1_f64),
+            ("RNDR/USDT", 1_f64),
             ("RSR/USDT", 1_f64),
             ("SAND/USDT", 1_f64),
             ("SC/USDT", 1_f64),
             ("SDN/USDT", 0.1_f64),
+            ("SFP/USDT", 1_f64),
             ("SHIB/USDT", 1000_f64),
             ("SKL/USDT", 1_f64),
             ("SLP/USDT", 1_f64),
             ("SNX/USDT", 0.1_f64),
             ("SOL/USDT", 0.1_f64),
+            ("SOS/USDT", 1000000_f64),
+            ("SPA/USDT", 100_f64),
+            ("SPELL/USDT", 100_f64),
             ("SRM/USDT", 0.1_f64),
+            ("SSS/USDT", 0.1_f64),
             ("STARL/USDT", 100000_f64),
             ("STMX/USDT", 1_f64),
             ("STORJ/USDT", 1_f64),
@@ -150,8 +172,10 @@ lazy_static! {
             ("SXP/USDT", 1_f64),
             ("THETA/USDT", 1_f64),
             ("TLM/USDT", 1_f64),
+            ("TNS/USDT", 1_f64),
             ("TONCOIN/USDT", 1_f64),
             ("TORN/USDT", 0.01_f64),
+            ("TRVL/USDT", 1_f64),
             ("TRX/USDT", 10_f64),
             ("UMA/USDT", 0.1_f64),
             ("UNI/USDT", 0.1_f64),
